[gparted] Use Gtk::Box for Dialog_FileSystem_Label (!25)



commit 784a4977b115b504e58cd67dcb56a67c1620cd14
Author: Luca Bacci <luca bacci982 gmail com>
Date:   Wed Feb 27 16:47:58 2019 +0100

    Use Gtk::Box for Dialog_FileSystem_Label (!25)
    
    Gtk::HBox and Gtk::VBox were deprecated in Gtkmm 3.2.  Replace with
    plain Gtk::Box.
    
    This commit makes the change for Dialog_FileSystem_Label.cc.
    
    Closes !25 - Modern Gtk3 - part 1

 src/Dialog_FileSystem_Label.cc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/Dialog_FileSystem_Label.cc b/src/Dialog_FileSystem_Label.cc
index 1f8e808c..b9f64cdf 100644
--- a/src/Dialog_FileSystem_Label.cc
+++ b/src/Dialog_FileSystem_Label.cc
@@ -33,8 +33,8 @@ Dialog_FileSystem_Label::Dialog_FileSystem_Label( const Partition & partition )
        /* TO TRANSLATORS: dialog title, looks like   Set file system label on /dev/hda3 */
        this->set_title( Glib::ustring::compose( _("Set file system label on %1"), partition.get_path() ) );
 
-       // HBox to hold the label and entry box line
-       Gtk::HBox *hbox( manage( new Gtk::HBox() ) );
+       // Horizontal box to hold the label and entry box line
+       Gtk::Box *hbox(manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)));
        hbox->set_border_width( 5 );
        hbox->set_spacing( 10 );
        get_vbox()->pack_start( *hbox, Gtk::PACK_SHRINK );


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]